<?php

/**
 * Yandex Money Form package for Concrete5
 * Copyright 2020, Alex Borisov. All Rights Reserved.
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 * 
 * @author Alex Borisov <linuxoidoz@gmail.com>
 * @copyright 2018-2020, Alex Borisov. All Rights Reserved.
 * @package Concrete\Package\ab_yandex_money_form
 */

namespace Concrete\Package\AbYandexMoneyForm\Block\AbYandexMoneyForm;

use Concrete\Core\Block\BlockController;

class Controller extends BlockController
{
    
    protected $btWrapperClass = 'ccm-ui';
    protected $btInterfaceWidth = "600";
    protected $btInterfaceHeight = "600";
    protected $btTable = 'btAbYandexMoneyForm';
    
    protected $form_types = array();
    protected $payment_labels = array();
    
    public function getBlockTypeDescription() 
    {
        return t("Add Yandex Money Form block");
    }

    public function getBlockTypeName() 
    {
        return t("Yandex Money Form");
    }

    public function on_start()
    {
        $this->set('app', $this->app);
        
        $this->form_types = ['shop' => t('Universal Form'), 'small' => t('Button'), 'donate' => t('Donation Form')];
        $this->payment_labels = [t('Text'), t('Text with Random Unique String'), t('Text with Date-Time String'), t('Random Unique String'), t('Date-Time String')];
    }
    
    public function add()
    {
        $this->set('form_types', $this->form_types);
        $this->set('payment_labels', $this->payment_labels);
    }
    
    public function edit()
    {
        $this->set('form_types', $this->form_types);
        $this->set('payment_labels', $this->payment_labels);
    }
    
    public function save($data)
    {
        $data['form_title'] = isset($data['form_title']) ? $data['form_title'] : '';
        $data['btn_text'] = isset($data['btn_text']) ? $data['btn_text'] : t('Pay');
        
        $data['wallet'] = isset($data['wallet']) ? $data['wallet'] : '';
        $data['form_type'] = isset($data['form_type']) ? $data['form_type'] : '';
        $data['payment_targets_text'] = isset($data['payment_targets_text']) ? $data['payment_targets_text'] : '';
        $data['payment_targets_uid'] = isset($data['payment_targets_uid']) ? $data['payment_targets_uid'] : 0;
        $data['payment_targets'] = $data['payment_targets_uid'] ? $data['payment_targets_text'] . ' ' . date('YmdHis', time()) : $data['payment_targets_text'];
        $data['payment_ac'] = isset($data['payment_ac']) ? $data['payment_ac'] : 0;
        $data['payment_pc'] = isset($data['payment_pc']) ? $data['payment_pc'] : 0;
        $data['payment_mc'] = isset($data['payment_mc']) ? $data['payment_mc'] : 0;
        $data['payment_sum'] = isset($data['payment_sum']) ? $data['payment_sum'] : '';
        $data['allow_user_sum'] = isset($data['allow_user_sum']) ? $data['allow_user_sum'] : 0;
        
        $data['payment_formcomment'] = isset($data['payment_formcomment']) ? $data['payment_formcomment'] : '';
        $data['payment_short_dest'] = isset($data['payment_short_dest']) ? $data['payment_short_dest'] : '';
        $data['payment_label'] = isset($data['payment_label']) ? $data['payment_label'] : '';
        $data['payment_label_select'] = isset($data['payment_label_select']) ? $data['payment_label_select'] : 0;
        $data['payment_label_text'] = isset($data['payment_label_text']) ? $data['payment_label_text'] : '';
        switch ($data['payment_label_select']) {
            case 0:
                $data['payment_label'] = $data['payment_label_text'];
                break;
            case 1:
                $data['payment_label'] = $data['payment_label_text'] . ' ' . uniqid();
                break;
            case 2:
                $data['payment_label'] = $data['payment_label_text'] . ' ' . date('YmdHis', time());
                break;
            case 3:
                $data['payment_label'] = uniqid();
                break;
            case 4:
                $data['payment_label'] = date('YmdHis', time());
                break;
        }
        $data['payment_comment'] = isset($data['payment_comment']) ? $data['payment_comment'] : 0;
        $data['need_fio'] = isset($data['need_fio']) ? $data['need_fio'] : 0;
        $data['need_email'] = isset($data['need_email']) ? $data['need_email'] : 0;
        $data['need_phone'] = isset($data['need_phone']) ? $data['need_phone'] : 0;
        $data['need_address'] = isset($data['need_address']) ? $data['need_address'] : 0;
        $data['success_url_page_id'] = isset($data['success_url_page_id']) ? $data['success_url_page_id'] : 0;
        parent::save($data);
    }
}
